import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_details_action_buttons.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/subspace_chip.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_space/presentation/bloc/space_details_model_bloc/space_details_model_bloc.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SpaceSubSpacesDialog extends StatelessWidget {
  const SpaceSubSpacesDialog({
    required this.subspaces,
    super.key,
  });

  final List<Subspace> subspaces;

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: const Text('Create Sub Spaces'),
      content: TextFieldSubSpaceDialogWidget(
        subSpaces: subspaces,
      ),
      actions: [
        SpaceDetailsActionButtons(
          onSave: () {},
          onCancel: Navigator.of(context).pop,
        )
      ],
    );
  }
}

class TextFieldSubSpaceDialogWidget extends StatefulWidget {
  const TextFieldSubSpaceDialogWidget({
    super.key,
    required this.subSpaces,
  });

  final List<Subspace> subSpaces;

  @override
  State<TextFieldSubSpaceDialogWidget> createState() => _TextFieldSubSpaceDialogWidgetState();
}

class _TextFieldSubSpaceDialogWidgetState extends State<TextFieldSubSpaceDialogWidget> {

  late final TextEditingController _subspaceNameController;

  @override
  void initState() {
    super.initState();
    _subspaceNameController = TextEditingController();
  }

  @override
  void dispose() {
    _subspaceNameController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: context.screenWidth * 0.35,
      padding: const EdgeInsets.symmetric(
        vertical: 10,
        horizontal: 16,
      ),
      decoration: BoxDecoration(
        color: ColorsManager.boxColor,
        borderRadius: BorderRadius.circular(10),
      ),
      child: Wrap(
        spacing: 8,
        runSpacing: 8,
        alignment: WrapAlignment.start,
        crossAxisAlignment: WrapCrossAlignment.center,
        children: [
          ...widget.subSpaces.asMap().entries.map(
            (entry) {
              final index = entry.key;
              final subSpace = entry.value;

              final lowerName = subSpace.name.toLowerCase();

              final duplicateIndices = widget.subSpaces
                  .asMap()
                  .entries
                  .where((e) => e.value.name.toLowerCase() == lowerName)
                  .map((e) => e.key)
                  .toList();
              final isDuplicate = duplicateIndices.length > 1 &&
                  duplicateIndices.indexOf(index) != 0;
              return SubspaceChip(
                subSpace: subSpace,
                isDuplicate: isDuplicate,
                onDeleted: () => context.read<SpaceDetailsModelBloc>().add(
                      UpdateSpaceDetailsSubspaces(
                        widget.subSpaces.where((e) => e.uuid != subSpace.uuid).toList(),
                      ),
                    ),
              );
            },
          ),
          SizedBox(
            width: 200,
            child: TextField(
              controller: _subspaceNameController,
              decoration: InputDecoration(
                border: InputBorder.none,
                hintText: widget.subSpaces.isEmpty ? 'Please enter the name' : null,
                hintStyle: context.textTheme.bodySmall?.copyWith(
                  color: ColorsManager.lightGrayColor,
                ),
              ),
              onSubmitted: (value) {
                final trimmedValue = value.trim();
                if (trimmedValue.isNotEmpty) {
                  context.read<SpaceDetailsModelBloc>().add(
                        UpdateSpaceDetailsSubspaces(
                          [
                            ...widget.subSpaces,
                            Subspace(
                              name: trimmedValue,
                              uuid: '',
                              productAllocations: const [],
                            ),
                          ],
                        ),
                      );
                  _subspaceNameController.clear();
                }
              },
              style: context.textTheme.bodyMedium,
            ),
          ),
        ],
      ),
    );
  }
}
