import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_space/presentation/bloc/space_details_model_bloc/space_details_model_bloc.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SubspaceNameDisplayWidget extends StatefulWidget {
  const SubspaceNameDisplayWidget({super.key, required this.subSpace});

  final Subspace subSpace;

  @override
  State<SubspaceNameDisplayWidget> createState() =>
      _SubspaceNameDisplayWidgetState();
}

class _SubspaceNameDisplayWidgetState extends State<SubspaceNameDisplayWidget> {
  late final TextEditingController _controller;
  bool isEditing = false;
  @override
  void initState() {
    _controller = TextEditingController(text: widget.subSpace.name);
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final textStyle = context.textTheme.bodySmall?.copyWith(
      color: ColorsManager.spaceColor,
    );
    return InkWell(
      onTap: () => setState(() => isEditing = true),
      child: Visibility(
        visible: isEditing,
        replacement: Text(
          widget.subSpace.name,
          style: textStyle,
        ),
        child: TextField(
          controller: _controller,
          style: textStyle,
          decoration: const InputDecoration(
            border: InputBorder.none,
            contentPadding: EdgeInsetsDirectional.symmetric(
              horizontal: 8,
            ),
          ),
          onSubmitted: (value) {
            final bloc = context.read<SpaceDetailsModelBloc>();
            bloc.add(
              UpdateSpaceDetailsSubspaces(
                bloc.state.subspaces
                    .map(
                      (e) => e.uuid == widget.subSpace.uuid
                          ? e.copyWith(name: value)
                          : e,
                    )
                    .toList(),
              ),
            );
          },
        ),
      ),
    );
  }
}
